@@ -2,7 +2,6 @@ package Weather::Com::DateTime;
 
 use 5.006;
 use strict;
-no warnings;
 
 #use warnings;
 use Carp;
@@ -10,7 +9,7 @@ use Data::Dumper;
 use Time::Format;
 use Time::Local;
 
-our $VERSION = sprintf "%d.%03d", q$Revision: 1.7 $ =~ /(\d+)/g;
+our $VERSION = sprintf "%d.%03d", q$Revision: 1.3 $ =~ /(\d+)/g;
 
 our %months = (
 	'Jan' => 0,
@@ -35,12 +34,9 @@ sub new {
 	my $class = ref($proto) || $proto;
 	my $self  = {};
 
-	$self->{EPOC} = timelocal(gmtime(time()));
+	$self->{EPOC} = time();
 	if (@_) {
-		$self->{ZONE} = shift;
-	}
-	else {
-		$self->{ZONE} = 0;
+		$self->{EPOC} = shift;
 	}
 
 	bless( $self, $class );
@@ -51,26 +47,24 @@ sub new {
 #------------------------------------------------------------------------
 # very special setter methods
 #------------------------------------------------------------------------
-# this method assumes that time is irrelevant => no conversion needed
 sub set_date {
-	my $self       = shift;
-	my $datestring = shift;
-	my $month      = substr( $datestring, 0, 3 );
-	my $day        = substr( $datestring, 3 );
-	my @now        = gmtime();
+	my $self        = shift;
+	my $datestring  = shift;
+	my $monthstring = substr( $datestring, 0, 3 );
+	my $daystring   = substr( $datestring, 3 );
+	my @now         = localtime();
 
-	my $localmidnight = undef;
-	eval { $localmidnight = timelocal( 0, 0, 0, $day, $months{$month}, $now[5] ); };
+	eval {
+		$self->{EPOC} =
+		  timegm( 0, 0, 0, $daystring, $months{$monthstring}, $now[5] );
+	};
 	if ($@) {
 		croak($@);
 	}
 
-	my $gmtime = $localmidnight - ( $self->{ZONE} * 3600 );
-	$self->{EPOC} = $gmtime;
 	return $self->{EPOC};
 }
 
-# this method assumes that the date is irrelevant!
 sub set_time {
 	my $self       = shift;
 	my $timestring = shift;
@@ -79,21 +73,16 @@ sub set_time {
 	my $minute     = substr( $timestring, $colon + 1, 2 );
 	my $ampm       = substr( $timestring, $colon + 4 );
 	$hour += 12 if ( lc($ampm) eq "pm" );
+	my @now = localtime();
 
-	my @now       = gmtime();
-	my $localtime = undef;
 	eval {
-		$localtime = timelocal( 0, $minute, $hour, $now[3], $now[4], $now[5] );
+		$self->{EPOC} =
+		  timelocal( 0, $minute, $hour, $now[3], $now[4], $now[5] );
 	};
 	if ($@) {
 		croak($@);
 	}
-	if ($@) {
-		croak($@);
-	}
 
-	my $gmtime = $localtime - ( $self->{ZONE} * 3600 );
-	$self->{EPOC} = $gmtime;
 	return $self->{EPOC};
 }
 
@@ -111,43 +100,33 @@ sub set_lsup {
 	$year += 100;
 	$hour += 12 if ( $ampm eq "PM" );
 
-	my $localtime;
-	eval { $localtime = timelocal( 0, $min, $hour, $mday, $mon - 1, $year ); };
+	eval {
+		$self->{EPOC} = timelocal( 0, $min, $hour, $mday, $mon - 1, $year );
+	};
 	if ($@) {
 		croak($@);
 	}
 
-	my $gmtime = $localtime - ( $self->{ZONE} * 3600 );
-	$self->{EPOC} = $gmtime;
 	return $self->{EPOC};
 }
 
 #------------------------------------------------------------------------
 # Access date and time
 #------------------------------------------------------------------------
-# epoc is alway GMT
 sub epoc {
 	my $self = shift;
 
 	if (@_) {
-		$self->{EPOC} = timelocal(gmtime(shift));
+		$self->{EPOC} = shift;
 	}
 
-	# we have to fake up $epoc
-	# because of Time::Format behaviour, $epoc has to be in localtime
-	# and to be able to provide a GMT conform epoc, we have to transform
-	# this here
-	return timegm(localtime($self->{EPOC}));
+	return $self->{EPOC};
 }
 
 sub formatted {
-	my $self      = shift;
-	my $format    = shift;
-	
-	# Time::Format always returns localtime of the server the
-	# script runs on. We have to eliminate this.
-	my $localepoc = $self->{EPOC} + ( $self->{ZONE} * 3600 );
-	return $time{ $format, $localepoc };    
+	my $self   = shift;
+	my $format = shift;
+	return $time{ $format, $self->{EPOC} };
 }
 
 #------------------------------------------------------------------------
@@ -155,32 +134,32 @@ sub formatted {
 #------------------------------------------------------------------------
 sub weekday {
 	my $self = shift;
-	return $self->formatted('Weekday');
+	return $time{ 'Weekday', $self->{EPOC} };
 }
 
 sub date {
 	my $self = shift;
-	return $self->formatted('d. Month yyyy');
+	return $time{ 'd. Month yyyy', $self->{EPOC} };
 }
 
 sub year {
 	my $self = shift;
-	return $self->formatted('yyyy');
+	return $time{ 'yyyy', $self->{EPOC} };
 }
 
 sub month {
 	my $self = shift;
-	return $self->formatted('Month');
+	return $time{ 'Month', $self->{EPOC} };
 }
 
 sub mon {
 	my $self = shift;
-	return $self->formatted('mm{on}');
+	return $time{ 'mm{on}', $self->{EPOC} };
 }
 
 sub day {
 	my $self = shift;
-	return $self->formatted('dd');
+	return $time{ 'dd', $self->{EPOC} };
 }
 
 #------------------------------------------------------------------------
@@ -188,12 +167,12 @@ sub day {
 #------------------------------------------------------------------------
 sub time {
 	my $self = shift;
-	return $self->formatted('hh:mm');
+	return $time{ 'hh:mm', $self->{EPOC} };
 }
 
 sub time_ampm {
 	my $self = shift;
-	return $self->formatted('H:mm AM');
+	return $time{ 'H:mm AM', $self->{EPOC} };
 }
 
 #------------------------------------------------------------------------
@@ -236,16 +215,10 @@ Weather::Com::DateTime - date and time class
   #!/usr/bin/perl -w
   use Weather::Com::DateTime;
   
-  my $gmt_offset = 1; # e.g. for Germany in winter
-  my $datetime = Weather::Com::DateTime->new($gmt_offset);
-  $datetime->set_lsup('02/25/05 11:21 PM Local Time');
-  
-  print "This is the date '02/25/05 11:21 PM' in Germany:\n";
-  print "Epoc:                    ", $datetime->epoc(), "\n";
-  print "GMT (UTC):               ". gmtime($datetime->epoc()). "\n";
-  print "My local time:           ". localtime($datetime->epoc()). "\n";
-  print "And finally German time: ", $datetime->time(), " o'clock at ", 
-  	$datetime->date(), "\n\n";
+  my $now = time();
+  my $datetime = Weather::Com::DateTime->new($now);
+  print "Today it's the ", $datetime->date(), "\n";
+  print "and it's currently ", $datetime->time(), "o'clock.\n";
 
 =head1 DESCRIPTION
 
@@ -257,25 +230,6 @@ present it in your programs using I<Weather::Com>. This class provides
 some predefined formats for date and time but also enables you to
 easily define your own ones.
 
-These objects always represent the local time of a I<Weather::Com::Location>
-object. That is, if you have a location object for New York City and your
-server running the weather script is located in Los Angeles, for example,
-this line
-
-  print "Sunrise at: ", $location->sunrise()->time(), "\n";
-
-will print the time of sunrise (in 24h format) in EST and not corresponding
-to the timezone of Los Angeles! If you'd like to now what this is in GMT 
-you could call
-
-  print "Sunrise at: ". gmtime($location->sunrise()->epoc()). "\n";
-
-or if you want to know when the sun rises at the location in your
-servers local time than just call
-
-  print "Sunrise at: ". localtime($location->sunrise()->epoc()). "\n";
-
-
 There are two ways to get your own date or time format:
 
 =over 4
@@ -300,23 +254,68 @@ You usually would not construct an object of this class yourself.
 This is implicitely done when you call one of the OO interfaces
 date or time methods.
 
-The constructor can take a GMT offset in positive or negative hours.
+The constructor can take a time in epoc seconds.
 
-If one calls the constructor without any GMT offset, we assume you want
-a GMT object.
+=head1 INTERFACE
+
+This class can simply be customized to fit your personal needs. 
+
+If you have your own special date and time formats you always want 
+to use in your programm, simply change the default ones.
+
+If you sometimes need another format than usual, use the C<formatted()>
+method instead, providing a date or time format string to it, corresponding
+to the I<Time::Format> module.
+
+The following methods should not be removed because they make up the interface
+of the class as used by the rest of I<Weather::Com>:
+
+=over 4
+
+=item *
+
+C<set_date()>
+
+=item *
+
+C<set_time()>
+
+=item *
+
+C<set_lsup()>
+
+=item *
+
+C<date()>
+
+=item *
+
+C<time()>
+
+=item *
+
+C<time_ampm()>
+
+=back
+
+All these methods are needed by the other classes.
+
+Please do not touch the setter methods and the 'ampm' method.
+
+The methods C<date()> and C<time()> can be adjusted by you to fit
+your date and time format wishes, as long as they return anything.
 
 =head1 METHODS
 
 =head2 epoc(epoc seconds)
 
-With this method you can set the date and time using epocs (GMT) directly.
+With this method you can set the date and time using epocs directly.
 
-It returns the currently set epoc seconds (GMT).
+It returns the currently set epoc seconds.
 
 =head2 formatted(format)
 
-This method returns a date or time formatted in the way you ask for and
-corresponding to the local time of the parent object.
+This method returns a date or time formatted in the way you ask for.
 
 The C<format> you provide to this method has to be a valid I<Time::Format>
 format. For details please refer to L<Time::Format>.
@@ -382,7 +381,7 @@ Thomas Schnuecker, E<lt>thomas@schnuecker.deE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2004-2007 by Thomas Schnuecker
+Copyright (C) 2004-2005 by Thomas Schnuecker
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
