@@ -7,7 +7,7 @@ use Data::Dumper;
 use Weather::Com::DayForecast;
 use base "Weather::Com::Cached";
 
-our $VERSION = sprintf "%d.%03d", q$Revision: 1.6 $ =~ /(\d+)/g;
+our $VERSION = sprintf "%d.%03d", q$Revision: 1.3 $ =~ /(\d+)/g;
 
 #------------------------------------------------------------------------
 # Constructor
@@ -97,15 +97,13 @@ sub _build_forecasts {
 	unless ( $self->{DAYS} ) {
 		for ( my $i = 0 ; $i < 10 ; $i++ ) {
 			$self->_debug("Initializing forecast for day $i");
-			$self->{DAYS}->[$i] = Weather::Com::DayForecast->new($self->{ARGS});
+			$self->{DAYS}->[$i] = Weather::Com::DayForecast->new();
 		}
 	}
 
 	# then update the DayForecast objects
-	# but put the timeszone into it...
 	foreach my $day ( @{ $self->{WEATHER}->{dayf}->{day} } ) {
-		my %args = (%{$day}, (zone => $self->{ARGS}->{zone}));
-		$self->{DAYS}->[ $day->{d} ]->update(\%args);
+		$self->{DAYS}->[ $day->{d} ]->update($day);
 	}
 
 	return 1;
@@ -185,7 +183,7 @@ Thomas Schnuecker, E<lt>thomas@schnuecker.deE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2004-2007 by Thomas Schnuecker
+Copyright (C) 2004-2005 by Thomas Schnuecker
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
